@@ -194,7 +194,7 @@ Action::ActionType ExecuteAction::actionType() const
 QString ExecuteAction::actionTip() const
 {
     Q_D(const Okular::ExecuteAction);
-    return i18n("Execute '%1'...", d->m_fileName);
+    return i18n("Execute '%1'…", d->m_fileName);
 }
 
 QString ExecuteAction::fileName() const
@@ -240,10 +240,8 @@ Action::ActionType BrowseAction::actionType() const
 QString BrowseAction::actionTip() const
 {
     Q_D(const Okular::BrowseAction);
-    QString source;
-    int row = 0, col = 0;
-    if (extractLilyPondSourceReference(d->m_url, &source, &row, &col)) {
-        return sourceReferenceToolTip(source, row, col);
+    if (auto ref = extractLilyPondSourceReference(d->m_url)) {
+        return sourceReferenceToolTip(*ref);
     }
     return d->m_url.toDisplayString();
 }
@@ -311,9 +309,9 @@ QString DocumentAction::actionTip() const
     case EndPresentation:
         return i18n("End Presentation");
     case Find:
-        return i18n("Find...");
+        return i18n("Find…");
     case GoToPage:
-        return i18n("Go To Page...");
+        return i18n("Go To Page…");
     case Close:
     default:;
     }
@@ -364,7 +362,7 @@ Action::ActionType SoundAction::actionType() const
 
 QString SoundAction::actionTip() const
 {
-    return i18n("Play sound...");
+    return i18n("Play sound…");
 }
 
 double SoundAction::volume() const
@@ -482,7 +480,7 @@ Action::ActionType MovieAction::actionType() const
 
 QString MovieAction::actionTip() const
 {
-    return i18n("Play movie...");
+    return i18n("Play movie…");
 }
 
 MovieAction::OperationType MovieAction::operation() const
