@@ -11,12 +11,12 @@
 #include <QDomDocument>
 #include <QDomElement>
 #include <QFont>
-#include <QLinkedList>
 #include <QRect>
 #include <QString>
 
 #include "area.h"
 #include "okularcore_export.h"
+#include "signatureutils.h"
 
 namespace Okular
 {
@@ -35,6 +35,7 @@ class LineAnnotationPrivate;
 class GeomAnnotationPrivate;
 class HighlightAnnotationPrivate;
 class StampAnnotationPrivate;
+class SignatureAnnotationPrivate;
 class InkAnnotationPrivate;
 class CaretAnnotationPrivate;
 class FileAttachmentAnnotationPrivate;
@@ -43,6 +44,7 @@ class MovieAnnotationPrivate;
 class ScreenAnnotationPrivate;
 class WidgetAnnotationPrivate;
 class RichMediaAnnotationPrivate;
+class NewSignatureData;
 
 /**
  * @short Helper class for (recursive) annotation retrieval/storage.
@@ -84,7 +86,8 @@ public:
      *
      * @since 21.12
      */
-    static QPixmap loadStamp(const QString &nameOrPath, int size, bool keepAspectRatio = true);
+    OKULARCORE_DEPRECATED static QPixmap loadStamp(const QString &nameOrPath, int size, bool keepAspectRatio = true);
+    static QPixmap loadStamp(const QString &nameOrPath, QSize size, Qt::AspectRatioMode aspectRatio = Qt::KeepAspectRatio);
 };
 
 /**
@@ -604,12 +607,12 @@ public:
     /**
      * Returns a reference to the revision list of the annotation.
      */
-    QLinkedList<Revision> &revisions();
+    QList<Revision> &revisions();
 
     /**
      * Returns a reference to the revision list of the annotation.
      */
-    const QLinkedList<Revision> &revisions() const;
+    const QList<Revision> &revisions() const;
 
     /**
      * Sets the "native" @p id of the annotation.
@@ -682,8 +685,29 @@ public:
      *
      * @since 0.17 (KDE 4.11)
      */
+
     void setAnnotationProperties(const QDomNode &node);
 
+    /**
+     * Sets some native internal data with shared ownership.
+     *
+     * data is kept alive according to shared_ptr refcount.
+     *
+     * Can be cleared in here with just setting a nullptr.
+     *
+     * @since 24.12
+     */
+    void setNativeData(std::shared_ptr<void> data);
+
+    /**
+     * @returns the native data content, or nullptr if nothing set.
+     *
+     * You set it, you know what's in it
+     *
+     * @since 24.12
+     */
+    const void *nativeData() const;
+
 protected:
     /// @cond PRIVATE
     explicit Annotation(AnnotationPrivate &dd);
@@ -938,19 +962,25 @@ public:
 
     /**
      * Sets the normalized line @p points of the line annotation.
+     *
+     * @since 22.08
      */
-    void setLinePoints(const QLinkedList<NormalizedPoint> &points);
+    void setLinePoints(const QList<NormalizedPoint> &points);
 
     /**
      * Returns the normalized line points of the line annotation.
+     *
+     * @since 22.08
      */
-    QLinkedList<NormalizedPoint> linePoints() const;
+    QList<NormalizedPoint> linePoints() const;
 
     /**
      * Returns the transformed (e.g. rotated) normalized line points
      * of the line annotation.
+     *
+     * @since 22.08
      */
-    QLinkedList<NormalizedPoint> transformedLinePoints() const;
+    QList<NormalizedPoint> transformedLinePoints() const;
 
     /**
      * Sets the line starting @p style of the line annotation.
@@ -1316,6 +1346,76 @@ private:
     Q_DISABLE_COPY(StampAnnotation)
 };
 
+#if HAVE_NEW_SIGNATURE_API
+/**
+ * \since 24.12
+ */
+class OKULARCORE_EXPORT SignatureAnnotation : public Annotation
+{
+public:
+    /**
+     * Creates a new signature annotation.
+     */
+    SignatureAnnotation();
+
+    /**
+     * Destroys the signature annotation.
+     */
+    ~SignatureAnnotation() override;
+
+    QString text() const;
+    void setText(const QString &text);
+
+    QString leftText() const;
+    void setLeftText(const QString &text);
+
+    QString imagePath() const;
+    void setImagePath(const QString &imagePath);
+
+    QString fieldPartialName() const;
+    void setFieldPartialName(const QString &fieldPartialName);
+
+    double fontSize() const;
+    void setFontSize(double fontSize);
+
+    double leftFontSize() const;
+    void setLeftFontSize(double fontSize);
+
+    int page() const;
+    void setPage(int page);
+
+    /**
+     * Sets the function to actually implement the signing
+     *
+     * \since 25.08
+     */
+    void setSignFunction(std::function<std::pair<SigningResult, QString>(const Okular::NewSignatureData &, const QString &)> func);
+
+    /**
+     * \brief signs this signature annotation
+     * \return result and a detailed/advanced error message/code in case of failure
+     *
+     * \since 25.08
+     */
+    std::pair<SigningResult, QString> sign(const Okular::NewSignatureData &data, const QString &fileName);
+
+    /**
+     * Returns the sub type of the stamp annotation.
+     */
+    SubType subType() const override;
+
+    /**
+     * Stores the stamp annotation as xml in @p document
+     * under the given parent @p node.
+     */
+    void store(QDomNode &node, QDomDocument &document) const override;
+
+private:
+    Q_DECLARE_PRIVATE(SignatureAnnotation)
+    Q_DISABLE_COPY(SignatureAnnotation)
+};
+#endif
+
 class OKULARCORE_EXPORT InkAnnotation : public Annotation
 {
 public:
@@ -1336,19 +1436,25 @@ public:
 
     /**
      * Sets the @p paths of points for the ink annotation.
+     *
+     * @since 22.08
      */
-    void setInkPaths(const QList<QLinkedList<NormalizedPoint>> &paths);
+    void setInkPaths(const QList<QList<NormalizedPoint>> &paths);
 
     /**
      * Returns the paths of points of the ink annotation.
+     *
+     * @since 22.08
      */
-    QList<QLinkedList<NormalizedPoint>> inkPaths() const;
+    QList<QList<NormalizedPoint>> inkPaths() const;
 
     /**
      * Returns the paths of transformed (e.g. rotated) points of
      * the ink annotation.
+     *
+     * @since 22.08
      */
-    QList<QLinkedList<NormalizedPoint>> transformedInkPaths() const;
+    QList<QList<NormalizedPoint>> transformedInkPaths() const;
 
     /**
      * Returns the sub type of the ink annotation.
