@@ -26,7 +26,6 @@
 
 class dviRenderer;
 class KProcess;
-class QStringList;
 
 class DVIExport : public QObject, public QSharedData
 {
@@ -53,7 +52,7 @@ protected:
      *  that the external process has finished and that this variable
      *  can be removed from any stores.
      */
-    DVIExport(dviRenderer &parent);
+    explicit DVIExport(dviRenderer &parent);
 
     /** Spawns the external process having connected slots to the child
      *  process's stdin and stdout streams.
@@ -123,7 +122,7 @@ public:
      *  @param useFontHinting boolean that defines whether to use font hinting.
      *  @param orientation the original orientation of the document
      */
-    DVIExportToPS(dviRenderer &parent, const QString &output_name, const QStringList &options, QPrinter *printer, bool useFontHinting, QPrinter::Orientation orientation = QPrinter::Portrait);
+    DVIExportToPS(dviRenderer &parent, const QString &output_name, const QStringList &options, QPrinter *printer, bool useFontHinting, QPageLayout::Orientation orientation = QPageLayout::Portrait);
 
 private:
     void abort_process_impl() override;
@@ -132,7 +131,7 @@ private:
     QPrinter *printer_;
     QString output_name_;
     QString tmpfile_name_;
-    QPrinter::Orientation orientation_;
+    QPageLayout::Orientation orientation_;
 };
 
 #endif
