@@ -14,19 +14,30 @@
 
 class QString;
 
-
 class DVI_SourceFileSplitter
 {
 public:
-  DVI_SourceFileSplitter(const QString & srclink, const QString & dviFile);
+    DVI_SourceFileSplitter(const QString &srclink, const QString &dviFile);
 
-  QString  fileName() const { return m_fileInfo.fileName(); }
-  QString  filePath() const { return m_fileInfo.absoluteFilePath(); }
-  bool     fileExists() const { return m_fileInfo.exists(); }
-  quint32 line() const { return m_line; }
+    QString fileName() const
+    {
+        return m_fileInfo.fileName();
+    }
+    QString filePath() const
+    {
+        return m_fileInfo.absoluteFilePath();
+    }
+    bool fileExists() const
+    {
+        return m_fileInfo.exists();
+    }
+    quint32 line() const
+    {
+        return m_line;
+    }
 
 private:
-  QFileInfo m_fileInfo;
-  quint32  m_line;
+    QFileInfo m_fileInfo;
+    quint32 m_line;
 };
 #endif
