@@ -22,12 +22,12 @@
 
 #include <QApplication>
 #include <QDir>
+#include <QList>
 #include <QMutex>
 #include <QStack>
 #include <QString>
 #include <QTemporaryFile>
 #include <QUrl>
-#include <QVector>
 
 #include <KAboutData>
 #include <KLocalizedString>
@@ -41,6 +41,7 @@ OKULAR_EXPORT_PLUGIN(DviGenerator, "libokularGenerator_dvi.json")
 
 DviGenerator::DviGenerator(QObject *parent, const QVariantList &args)
     : Okular::Generator(parent, args)
+    , m_resolution {0}
     , m_fontExtracted(false)
     , m_docSynopsis(nullptr)
     , m_dviRenderer(nullptr)
@@ -54,7 +55,7 @@ DviGenerator::DviGenerator(QObject *parent, const QVariantList &args)
     }
 }
 
-bool DviGenerator::loadDocument(const QString &fileName, QVector<Okular::Page *> &pagesVector)
+bool DviGenerator::loadDocument(const QString &fileName, QList<Okular::Page *> &pagesVector)
 {
     // qCDebug(OkularDviDebug) << "file:" << fileName;
     QUrl base(QUrl::fromLocalFile(fileName));
@@ -225,48 +226,42 @@ QImage DviGenerator::image(Okular::PixmapRequest *request)
 
 Okular::TextPage *DviGenerator::textPage(Okular::TextRequest *request)
 {
+    if (!m_dviRenderer) {
+        return nullptr;
+    }
+
     const Okular::Page *page = request->page();
 
     qCDebug(OkularDviDebug);
-    dviPageInfo *pageInfo = new dviPageInfo();
-    pageSize ps;
+    dviPageInfo pageInfo;
 
-    pageInfo->width = page->width();
-    pageInfo->height = page->height();
+    pageInfo.width = page->width();
+    pageInfo.height = page->height();
 
-    pageInfo->pageNumber = page->number() + 1;
-
-    pageInfo->resolution = m_resolution;
+    pageInfo.pageNumber = page->number() + 1;
 
     QMutexLocker lock(userMutex());
 
     // get page text from m_dviRenderer
     Okular::TextPage *ktp = nullptr;
-    if (m_dviRenderer) {
-        SimplePageSize s = m_dviRenderer->sizeOfPage(pageInfo->pageNumber);
-        pageInfo->resolution = (double)(pageInfo->width) / ps.width().getLength_in_inch();
+    SimplePageSize s = m_dviRenderer->sizeOfPage(pageInfo.pageNumber);
+    pageInfo.resolution = (double)(pageInfo.width) / s.width().getLength_in_inch();
 
-        m_dviRenderer->getText(pageInfo);
-        lock.unlock();
+    m_dviRenderer->getText(&pageInfo);
+    lock.unlock();
 
-        ktp = extractTextFromPage(pageInfo);
-    }
-    delete pageInfo;
+    ktp = extractTextFromPage(pageInfo);
     return ktp;
 }
 
-Okular::TextPage *DviGenerator::extractTextFromPage(dviPageInfo *pageInfo)
+Okular::TextPage *DviGenerator::extractTextFromPage(const dviPageInfo &pageInfo)
 {
-    QList<Okular::TextEntity *> textOfThePage;
+    QList<Okular::TextEntity> textOfThePage;
 
-    QVector<TextBox>::ConstIterator it = pageInfo->textBoxList.constBegin();
-    QVector<TextBox>::ConstIterator itEnd = pageInfo->textBoxList.constEnd();
+    int pageWidth = pageInfo.width, pageHeight = pageInfo.height;
 
-    int pageWidth = pageInfo->width, pageHeight = pageInfo->height;
-
-    for (; it != itEnd; ++it) {
-        TextBox curTB = *it;
-        textOfThePage.push_back(new Okular::TextEntity(curTB.text, new Okular::NormalizedRect(curTB.box, pageWidth, pageHeight)));
+    for (const TextBox &curTB : std::as_const(pageInfo.textBoxList)) {
+        textOfThePage.push_back(Okular::TextEntity(curTB.text, Okular::NormalizedRect(curTB.box, pageWidth, pageHeight)));
     }
 
     Okular::TextPage *ktp = new Okular::TextPage(textOfThePage);
@@ -309,7 +304,7 @@ const Okular::DocumentSynopsis *DviGenerator::generateDocumentSynopsis()
 
     userMutex()->lock();
 
-    QVector<PreBookmark> prebookmarks = m_dviRenderer->getPrebookmarks();
+    QList<PreBookmark> prebookmarks = m_dviRenderer->getPrebookmarks();
 
     userMutex()->unlock();
 
@@ -319,8 +314,8 @@ const Okular::DocumentSynopsis *DviGenerator::generateDocumentSynopsis()
 
     QStack<QDomElement> stack;
 
-    QVector<PreBookmark>::ConstIterator it = prebookmarks.constBegin();
-    QVector<PreBookmark>::ConstIterator itEnd = prebookmarks.constEnd();
+    QList<PreBookmark>::ConstIterator it = prebookmarks.constBegin();
+    QList<PreBookmark>::ConstIterator itEnd = prebookmarks.constEnd();
     for (; it != itEnd; ++it) {
         QDomElement domel = m_docSynopsis->createElement((*it).title);
         Anchor a = m_dviRenderer->findAnchor((*it).anchorName);
@@ -389,7 +384,7 @@ Okular::FontInfo::List DviGenerator::fontsForPage(int page)
 
             of.setFile(fontFileName);
 
-            Okular::FontInfo::FontType ft;
+            Okular::FontInfo::FontType ft = Okular::FontInfo::Unknown;
             switch (font->getFontType()) {
             case TeXFontDefinition::TEX_PK:
                 ft = Okular::FontInfo::TeXPK;
@@ -403,6 +398,9 @@ Okular::FontInfo::List DviGenerator::fontsForPage(int page)
             case TeXFontDefinition::FREETYPE:
                 ft = Okular::FontInfo::TeXFreeTypeHandled;
                 break;
+            case TeXFontDefinition::UNKNOWN:
+                ft = Okular::FontInfo::Unknown;
+                break;
             }
             of.setType(ft);
 
@@ -419,7 +417,7 @@ Okular::FontInfo::List DviGenerator::fontsForPage(int page)
     return list;
 }
 
-void DviGenerator::loadPages(QVector<Okular::Page *> &pagesVector)
+void DviGenerator::loadPages(QList<Okular::Page *> &pagesVector)
 {
     QSize pageRequiredSize;
 
@@ -449,11 +447,11 @@ void DviGenerator::loadPages(QVector<Okular::Page *> &pagesVector)
 
         pagesVector[i] = page;
     }
-    qCDebug(OkularDviDebug) << "pagesVector successfully inizialized!";
+    qCDebug(OkularDviDebug) << "pagesVector successfully initialized!";
 
     // filling the pages with the source references rects
-    const QVector<DVI_SourceFileAnchor> &sourceAnchors = m_dviRenderer->sourceAnchors();
-    QVector<QList<Okular::SourceRefObjectRect *>> refRects(numofpages);
+    const QList<DVI_SourceFileAnchor> &sourceAnchors = m_dviRenderer->sourceAnchors();
+    QList<QList<Okular::SourceRefObjectRect *>> refRects(numofpages);
     for (const DVI_SourceFileAnchor &sfa : sourceAnchors) {
         if (sfa.page < 1 || (int)sfa.page > numofpages) {
             continue;
