@@ -7,6 +7,7 @@
 #include <qqml.h>
 
 #include "gui/certificatemodel.h"
+#include "gui/recentitemsmodel.h"
 
 class CertificateModelForeign : public QObject
 {
@@ -15,3 +16,10 @@ class CertificateModelForeign : public QObject
     QML_NAMED_ELEMENT(CertificateModel)
     QML_UNCREATABLE("")
 };
+
+class RecentItemsModelForeign : public QObject
+{
+    Q_OBJECT
+    QML_FOREIGN(RecentItemsModel)
+    QML_NAMED_ELEMENT(RecentItemsModel)
+};
