@@ -26,7 +26,6 @@
 #include "pageviewutils.h"
 #include <QAbstractScrollArea>
 #include <QList>
-#include <QVector>
 
 #include "signaturepartutils.h"
 
@@ -75,6 +74,9 @@ public:
         Cancelled,
     };
 
+    // inherited from QAbstractScrollArea
+    void setupViewport(QWidget *viewport) override;
+
     // create actions that interact with this widget
     void setupBaseActions(KActionCollection *ac);
     void setupViewerActions(KActionCollection *ac);
@@ -89,7 +91,7 @@ public:
     void displayMessage(const QString &message, const QString &details = QString(), PageViewMessage::Icon icon = PageViewMessage::Info, int duration = -1);
 
     // inherited from DocumentObserver
-    void notifySetup(const QVector<Okular::Page *> &pages, int setupFlags) override;
+    void notifySetup(const QList<Okular::Page *> &pages, int setupFlags) override;
     void notifyViewportChanged(bool smoothMove) override;
     void notifyPageChanged(int pageNumber, int changedFlags) override;
     void notifyContentsCleared(int changedFlags) override;
@@ -193,6 +195,10 @@ protected:
     void scrollContentsBy(int dx, int dy) override;
 
 private:
+    // Geometry bounds of the viewport for annotation windows, excludes scrollbars
+    const QRect &viewportBoundsForAnnotationWindows();
+    // Notify all annotation windows of the new viewport geometry, so they could reposition themselves
+    void notifyAnnotationWindowsAboutViewportBoundsChange();
     // draw background and items on the opened qpainter
     void drawDocumentOnPainter(const QRect contentsRect, QPainter *p);
     // update item width and height using current zoom parameters
