@@ -133,7 +133,7 @@ public:
     ~Part() override;
 
     // inherited from DocumentObserver
-    void notifySetup(const QVector<Okular::Page *> &pages, int setupFlags) override;
+    void notifySetup(const QList<Okular::Page *> &pages, int setupFlags) override;
     void notifyViewportChanged(bool smoothMove) override;
     void notifyPageChanged(int page, int flags) override;
 
@@ -146,7 +146,7 @@ public:
     void showSourceLocation(const QString &fileName, int line, int column, bool showGraphically = true) override;
     void clearLastShownSourceLocation() override;
     bool isWatchFileModeEnabled() const override;
-    void setWatchFileModeEnabled(bool enable) override;
+    void setWatchFileModeEnabled(bool enable) final;
     bool areSourceLocationsShownGraphically() const override;
     void setShowSourceLocationsGraphically(bool show) override;
     bool openNewFilesInTabs() const override;
@@ -187,12 +187,13 @@ public Q_SLOTS: // dbus
 
 Q_SIGNALS:
     void enablePrintAction(bool enable);
-    void openSourceReference(const QString &absFileName, int line, int column);
-    void viewerMenuStateChange(bool enabled);
+    void openSourceReference(const QString &absFileName, int line, int column); /* cppcheck-suppress duplInheritedMember; see viewerinterface*/
+    void viewerMenuStateChange(bool enabled);                                   /* cppcheck-suppress duplInheritedMember */
     void enableCloseAction(bool enable);
     void mimeTypeChanged(const QMimeType &mimeType);
     void urlsDropped(const QList<QUrl> &urls);
     void fitWindowToPage(const QSize pageViewPortSize, const QSize pageSize);
+    void maxRecentItemsChanged(const int);
     /**
      * Request to open a newly signed file
      * \param path file to open
@@ -282,6 +283,9 @@ public Q_SLOTS:
     void noticeMessage(const QString &message, int duration = -1);
 
     void moveSplitter(const int sideWidgetSize);
+#if HAVE_NEW_SIGNATURE_API
+    void finishSigning();
+#endif
 
 private:
     bool aboutToShowContextMenu(QMenu *menu, QAction *action, QMenu *contextMenu);
@@ -360,6 +364,9 @@ private:
     KMessageWidget *m_formsMessage;
     KMessageWidget *m_infoMessage;
     KMessageWidget *m_signatureMessage;
+#if HAVE_NEW_SIGNATURE_API
+    KMessageWidget *m_signatureInProgressMessage;
+#endif
     QPointer<ThumbnailList> m_thumbnailList;
     QPointer<PageView> m_pageView;
     QPointer<TOC> m_toc;
@@ -412,7 +419,6 @@ private:
     QAction *m_findPrev;
     QAction *m_save;
     QAction *m_saveAs;
-    QAction *m_saveCopyAs;
     QAction *m_printPreview;
     QAction *m_showProperties;
     QAction *m_showEmbeddedFiles;
@@ -468,6 +474,9 @@ private:
     // if we're opening http://localhost/foo#bar.pdf and the filename contains an # we can open it after trying to open foo fails
     QUrl m_urlWithFragment;
 
+    // Current value of maxRecentItems to detect value change, and inform shell
+    int m_maxRecentItems;
+
 private Q_SLOTS:
     void slotAccessibilityPreferences();
     void slotAnnotationPreferences();
